ConfigAPIHandler

Struct ConfigAPIHandler 

pub struct ConfigAPIHandler { /* private fields */ }
An API handler for returning the current configuration.

This handler exposes a single route – /config – that returns the current configuration in its serialized JSON form. This allows determining exactly how the process’ configuration looks based on the various providers being used, including any dynamic changes being applied.