pub struct ConfigWorker { /* private fields */ }Expand description
A worker for exposing an endpoint that returns the current configuration.
When running, the worker asserts a set of routes (based on ConfigAPIHandler) that allow querying the current
configuration. As the configuration may contain sensitive data, these routes are only present on the privileged API
endpoint.
Implementations
Sourceimpl ConfigWorker
impl ConfigWorker
Sourcepub fn new(snapshot: ConfigSnapshotFn) -> Self
pub fn new(snapshot: ConfigSnapshotFn) -> Self
Creates a new ConfigWorker that serves the snapshots produced by the given closure.